This crate contains kube-rs compatible bindings for Kubernetes custom resources for the k8s.nginx.org group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
k8s.nginx.org/v1
GlobalConfigurationPolicyTransportServerVirtualServerRouteVirtualServer
k8s.nginx.org/v1alpha1
GlobalConfigurationPolicyTransportServer